#
# spec file for package python-ironic-inspector-client
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-ironic-inspector-client
Version:        4.7.0
Release:        1.6
Summary:        Python client and CLI tool for Ironic Inspector
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-ironic-inspector-client
Source0:        https://files.pythonhosted.org/packages/source/p/python-ironic-inspector-client/python-ironic-inspector-client-4.7.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-fixtures
BuildRequires:  python3-openstackclient
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-osc-lib
BuildRequires:  python3-oslo.concurrency
BuildRequires:  python3-reno
BuildRequires:  python3-requests-mock
BuildRequires:  python3-testrepository
BuildArch:      noarch

%description
Ironic Inspector is an auxiliary service for discovering hardware properties
for a node managed by OpenStack Ironic. Hardware introspection or hardware
properties discovery is a process of getting hardware parameters required for
scheduling from a bare metal node, given its power management credentials
(e.g. IPMI address, user name and password).

This package contains Python client and command line tool for Ironic Inspector.

%package -n python3-ironic-inspector-client
Summary:        Python client and CLI tool for Ironic Inspector
Requires:       python3-PyYAML >= 3.13
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-openstackclient
Requires:       python3-osc-lib
Requires:       python3-oslo.i18n
Requires:       python3-oslo.utils
Requires:       python3-requests >= 2.14.2

%description -n python3-ironic-inspector-client
Ironic Inspector is an auxiliary service for discovering hardware properties
for a node managed by OpenStack Ironic. Hardware introspection or hardware
properties discovery is a process of getting hardware parameters required for
scheduling from a bare metal node, given its power management credentials
(e.g. IPMI address, user name and password).

This package contains Python client and command line tool for Ironic Inspector.

This package contains the Python 3.x module.

%prep
%autosetup -p1 -n python-ironic-inspector-client-4.7.0
sed -i -e 's,hacking.*,,' test-requirements.txt
sed -i -e 's,coverage.*,,' test-requirements.txt
sed -i -e 's,doc8.*,,' test-requirements.txt
%py_req_cleanup

%build
%py3_build

%install
%py3_install

%check
%{python_expand rm -rf .testrepository
python3 -m unittest discover ironic_inspector_client
}

%files -n python3-ironic-inspector-client
%doc README.rst
%license LICENSE
%{python3_sitelib}/ironic_inspector_client
%{python3_sitelib}/*.egg-info

%changelog
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 4.7.0
  * Improve testing
  * Add Python3 yoga unit tests
  * Update master for stable/xena
  * Replace deprecated assertDictContainsSubset
  * Update min version of tox to use allowlist
  * [doc] Fix lldp\_basic name
  * Expose more interface fields
  * Add Python3 xena unit tests
  * Update master for stable/wallaby
  * Remove redundant items from CI jobs
  * Update minversion of tox
  * Move pep8 dependencies from test-requirements to tox.ini
  * Remove lower-constraints job
  * Set safe version of hacking
  * Use python 3.8 in functional tests
  * Fix l-c job
  * Add Python3 wallaby unit tests
  * Update master for stable/victoria
* Tue Feb  2 2021 cloud-devel@suse.de
- update to version 4.4.0
  - Update TOX_CONSTRAINTS_FILE for stable/victoria
  - Update .gitreview for stable/victoria
  - Fix l-c job
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.3.0
  - Upgrade flake8-import-order version to 0.17.1
  - Switch to newer openstackdocstheme and reno versions
  - Tempest job to use the inherited devstack_services value
  - Support retrieving unprocessed data
  - Document the new standalone CLI
  - Follow up to update functest-requirements
  - Update master for stable/ussuri
  - Use unittest.mock instead of third party mock
  - Hacking: enforce usage of autospec=True in tests
  - Add py38 package metadata
  - Convert job to dib
  - Provide a clear error message when trying to access ironic (not inspector)
  - Add Python3 victoria unit tests
  - Update lower-constraints.txt
  - Set min version of tox to 3.2.1
  - Use only one job for tempest
  - Restore default netboot boot option
  - No need to import print function anymore
  - Update releasenotes conf
  - Fix pep8 job and functional job
  - Remove python3 from job name
  - Change parent for base job to ironic-inspector-base
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.1.0
  - Update the constraints url
  - Cleanup py27 support
  - Enforce running tox with correct python version based on env
  - Switch jobs to python3
  - Fixing base job
  - Bump hacking to 3.0.0
  - Make oslo.i18n an optional dependency
  - Stop using six library
  - Get rid of the oslo.utils requirement
  - Add bindep env and fix pdf doc generation
  - Recover the functional test
  - Add versions to release notes series
  - Move osc-lib to test-requirements
  - Drop python 2.7 support and testing
  - Update master for stable/train
  - Switch to Ussuri job
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 3.7.0
  - Fetch requirements from opendev
  - Bump the openstackdocstheme extension to 1.20
  - Update master for stable/stein
  - OpenDev Migration Patch
  - Update sphinx requirements
  - OSC: try fetching ironic-inspector URL from osc-lib
  - Find misteriously missing pep8 import check
  - Repair the deprecated uuid/uuids arguments
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Replace openstack.org git:// URLs with https://
  - CI: clean up required projects
  - Build pdf doc
  - Update Python 3 test runtimes for Train
  - Allow running a specific functional test via CLI
  - Dropping the py35 testing
  - Deprecates "uuid" parameters to Python calls when node is expected
  - Switch base job to ironic-base
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 3.5.0
  - Remove dsvm from zuulv3 job names
  - Support loading introspection rules from YAML files
  - Update tox.ini to support Python 3.x unit tests
  - Fix setup.cfg for release
  - add python 3.7 unit test job
  - Follow-up check-errors flag
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - CI: stop trying to pull the tempest plugin from ironic-inspector
  - Update min tox version to 2.0
  - Add check-errors flag to Introspection
  - switch documentation job to new PTI
  - Change basepython to python3
  - add python 3.6 unit test job
  - Zuul migration
  - import zuul job settings from project-config
* Tue Sep 11 2018 cloud-devel@suse.de
- update to version 3.3.0
  - fix tox python3 overrides
  - Add release note link in README
  - Trivial: Update pypi url to new url
  - Provide proper error message if interface name is invalid
  - Update the home-page link
  - Follow the new PTI for document build
  - Fix errors in package metadata
  - add lower-constraints job
  - Support passing manage_boot argument in Python API
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 3.2.0
  - Gate fix: Cap hacking to avoid gate failure
  - Update reno for stable/queens
  - Update links in README
  - Update bug tracker URL
  - Zuul: Remove project name
  - Switch the CI to hardware types and clean up playbook
  - Clean imports in code
  - Add the api help information
  - Updated from global requirements
  - Use the regular inspector tests in the CI
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 3.1.0 (bsc#1078607)
  - Updated from global requirements
  - Use the tempest plugin from openstack/ironic-tempest-plugin
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 3.0.0
  - Drop default URI, make either a session or inspector_url required
  - Documentation clean up
  - Remove deprecated setting ipmi creds feature
  - Update reno for stable/pike
  - Updated from global requirements
  - Add missing test on session + explicit URL
  - Centralize list of irrelevant files
  - Functional tests: pin *inspector* to HEAD
  - Using --option ARGUMENT
  - Remove setting of version/release from releasenotes
  - Move legacy python-ironic-inspector-client jobs
  - Remove deprecated ironic_inspector_client.client
  - Avoid tox_install.sh for constraints support
  - Update Inspector docs links in README
  - Remove support for passing auth_token to ClientV1
  - Add missing python-openstackclient to test-requirements
  - Use default tox environments for docs and releasenotes
  - Use functional tox environment
* Thu Sep 21 2017 cloud-devel@suse.de
- update to version 2.1.0
  - Update .gitreview for stable/pike
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.0.0
  - Do not depend on python-openstackclient
  - Introducing cli and contributor content
  - Remove log translations
  - Functional tests: pin *inspector* to HEAD
  - Introducing warning-is-error to docs
  - Make recent release note more readable
  - Update the documentation link for doc migration
  - Remove support for py34
  - Replace http with https
  - Update reno for stable/ocata
  - Add new introspection commands for interface data including lldp
  - Updated from global requirements
  - Switch from oslosphinx to openstackdocstheme
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.11.0:
  - Fix functional tests after recent API changes
  - Update reno for stable/newton
  - List introspection statuses support
  - Add simple Sphinx documentation
  - Add oslotest to test-requirements
  - Clarify that node names can be used in addition to UUIDs
  - Bump hacking to 0.11.0 in test-requirements
  - Show team and repo badges on README
  - Pin functest-requirements to a specific SHA
  - UUID, started_at, finished_at in the status
  - Enable release notes translation
  - Update to newer hacking
  - Deprecate setting IPMI credentials
  - Move documentation from README to Sphinx
  - TrivialFix: Remove logging import unused
  - Updated from global requirements
  - Rework handling requirements for functional tests
* Sun Oct  2 2016 dmueller@suse.com
- update to 1.9.0:
  * Sync tools/tox_install.sh
  * Using assertIsNone() is preferred over assertIs(None,..)
  * Switch to osc-lib instead of cliff
  * Add functional tests for CLI
  * Updated from global requirements
  * Increase verbosity for functional tests
  * Add functional test for wait_for_finish
  * Use constraints for all the things
  * Fix functional tests broken by the latest refactoring
  * Deprecate global functions in favor of ClientV1 methods
  * Updated from global requirements
  * Updated from global requirements
  * Add Python 3.5 tox env and detailed setup.cfg classifiers
  * Updated from global requirements
  * Add a test dependency on requests-mock
* Thu Sep  1 2016 tbechtold@suse.com
- Initial packaging (version 1.8.0)
